==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sv.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Ogiltig Federerad Moln-ID",
    "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
    "Couldn't establish a federated share." : "Kunde inte lägga till en federerad utdelning",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunde inte lägga till en federerad utdelning, lösenordet kanske var felaktigt.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federerad delningsförfrågan skickades, du kommer att få en inbjudan. Kontrollera dina aviseringar.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunde inte etablera federerad delning, det verkar som servern att federera med är för gammal (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Det är inte tillåtet att skicka federerade gruppdelningar från den här servern.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Delning av %1$s misslyckades eftersom det här objektet redan delas med kontot %2$s",
    "Not allowed to create a federated share to the same account" : "Inte tillåtet att skapa en federerad delning till samma konto",
    "Federated shares require read permissions" : "Federerade delningar kräver läsbehörighet",
    "File is already shared with %s" : "Filen är redan delad med %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Delning %1$s misslyckades. Kunde inte hitta %2$s, kanske är servern inte tillgänglig eller så används ett självsignerat certifikat.",
    "Could not find share" : "Kunde inte hitta delning",
    "Federated sharing" : "Federerad delning",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du tog emot {share} som en extern delning {user} (på uppdrag av {behalf})",
    "You received {share} as a remote share from {user}" : "Du tog emot {share} som en extern delning från {user}",
    "Accept" : "Acceptera",
    "Decline" : "Neka",
    "Federated Cloud Sharing" : "Federerad Moln-delning",
    "Sharing" : "Dela",
    "Federated file sharing" : "Federerad fildelning",
    "Provide federated file sharing across servers" : "Erbjuder federerad fildelning mellan servrar",
    "Confirm data upload to lookup server" : "Bekräfta datauppladdning till uppslagningstjänst",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "När detta är aktiverat kommer alla kontouppgifter (t.ex. e-postadress) med synlighetsomfång inställt på “publicerad” automatiskt att synkroniseras och överföras till ett externt system och göras tillgängliga i en offentlig, global adressbok.",
    "Disable upload" : "Inaktivera uppladdning",
    "Enable data upload" : "Aktivera datauppladdning",
    "Confirm querying lookup server" : "Bekräfta förfrågan till uppslagningstjänst",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "När detta är aktiverat kommer sökinmatningen vid skapande av delningar att skickas till ett externt system som tillhandahåller en offentlig och global adressbok.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Detta används för att hämta federerat moln-ID för att göra federerad delning enklare.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Dessutom kan användares e-postadresser skickas till systemet för att verifieras.",
    "Disable querying" : "Inaktivera förfrågningar",
    "Enable querying" : "Aktivera förfrågningar",
    "Unable to update federated files sharing config" : "Kunde inte uppdatera konfigurationen för federerad fildelning",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Anpassa hur användare kan dela mellan servrar. Detta inkluderar även delningar mellan användare på denna server ifall de använder federerad delning.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillåt användare på denna server att skicka delningar till andra servrar (denna inställning ger också WebDAV-tillgång till offentliga delningar)",
    "Allow people on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot delningar från andra servrar",
    "Allow people on this server to send shares to groups on other servers" : "Tillåt användare på denna server att skicka delningar till grupper på andra servrar",
    "Allow people on this server to receive group shares from other servers" : "Tillåt användare på denna server att ta emot gruppdelningar från andra servrar",
    "The lookup server is only available for global scale." : "Uppslagningstjänsten är endast tillgänglig för global scale.",
    "Search global and public address book for people" : "Sök global och offentlig adressbok för användare",
    "Allow people to publish their data to a global and public address book" : "Tillåt användare att publicera sin data till en global och publik adressbok",
    "Trusted federation" : "Betrodd federation",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Acceptera automatiskt delningar från betrodda federerade konton och grupper som standard",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Dela med mig genom mitt #Nextcloud federerade moln-ID, se {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dela med mig genom mitt #Nextcloud federerade moln-ID",
    "Share with me via Nextcloud" : "Dela med mig via Nextcloud",
    "Cloud ID copied to the clipboard" : "Moln-ID kopierades till urklippet",
    "Copy to clipboard" : "Kopiera till urklipp",
    "Clipboard not available. Please copy the cloud ID manually." : "Urklipp är inte tillgängligt. Kopiera moln-ID manuellt.",
    "Copied!" : "Kopierad!",
    "Federated Cloud" : "Federerat moln",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dela med alla som använder en Nextcloud-server eller andra Open Cloud Mesh (OCM) -kompatibla servrar och tjänster! Anger bara sitt federerade moln-ID i delningsrutan. Det ser ut som person@cloud.example.com",
    "Your Federated Cloud ID" : "Ditt federerade Moln-ID:",
    "Share it so your friends can share files with you:" : "Dela det så att dina vänner kan dela filer med dig:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (tidigare Twitter)",
    "formerly Twitter" : "tidigare Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Lägg till på din hemsida",
    "HTML Code:" : "HTML Kod:",
    "Cancel" : "Avbryt",
    "Add remote share" : "Lägg till extern delning",
    "Remote share" : "Extern delning",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till extern delning {name} från {owner}@{remote}?",
    "Remote share password" : "Lösenord för extern delning",
    "Incoming share could not be processed" : "Inkommande delning kunde inte behandlas"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sv.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Ogiltig Federerad Moln-ID",
    "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
    "Couldn't establish a federated share." : "Kunde inte lägga till en federerad utdelning",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunde inte lägga till en federerad utdelning, lösenordet kanske var felaktigt.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federerad delningsförfrågan skickades, du kommer att få en inbjudan. Kontrollera dina aviseringar.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunde inte etablera federerad delning, det verkar som servern att federera med är för gammal (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Det är inte tillåtet att skicka federerade gruppdelningar från den här servern.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Delning av %1$s misslyckades eftersom det här objektet redan delas med kontot %2$s",
    "Not allowed to create a federated share to the same account" : "Inte tillåtet att skapa en federerad delning till samma konto",
    "Federated shares require read permissions" : "Federerade delningar kräver läsbehörighet",
    "File is already shared with %s" : "Filen är redan delad med %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Delning %1$s misslyckades. Kunde inte hitta %2$s, kanske är servern inte tillgänglig eller så används ett självsignerat certifikat.",
    "Could not find share" : "Kunde inte hitta delning",
    "Federated sharing" : "Federerad delning",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du tog emot {share} som en extern delning {user} (på uppdrag av {behalf})",
    "You received {share} as a remote share from {user}" : "Du tog emot {share} som en extern delning från {user}",
    "Accept" : "Acceptera",
    "Decline" : "Neka",
    "Federated Cloud Sharing" : "Federerad Moln-delning",
    "Sharing" : "Dela",
    "Federated file sharing" : "Federerad fildelning",
    "Provide federated file sharing across servers" : "Erbjuder federerad fildelning mellan servrar",
    "Confirm data upload to lookup server" : "Bekräfta datauppladdning till uppslagningstjänst",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "När detta är aktiverat kommer alla kontouppgifter (t.ex. e-postadress) med synlighetsomfång inställt på “publicerad” automatiskt att synkroniseras och överföras till ett externt system och göras tillgängliga i en offentlig, global adressbok.",
    "Disable upload" : "Inaktivera uppladdning",
    "Enable data upload" : "Aktivera datauppladdning",
    "Confirm querying lookup server" : "Bekräfta förfrågan till uppslagningstjänst",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "När detta är aktiverat kommer sökinmatningen vid skapande av delningar att skickas till ett externt system som tillhandahåller en offentlig och global adressbok.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Detta används för att hämta federerat moln-ID för att göra federerad delning enklare.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Dessutom kan användares e-postadresser skickas till systemet för att verifieras.",
    "Disable querying" : "Inaktivera förfrågningar",
    "Enable querying" : "Aktivera förfrågningar",
    "Unable to update federated files sharing config" : "Kunde inte uppdatera konfigurationen för federerad fildelning",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Anpassa hur användare kan dela mellan servrar. Detta inkluderar även delningar mellan användare på denna server ifall de använder federerad delning.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillåt användare på denna server att skicka delningar till andra servrar (denna inställning ger också WebDAV-tillgång till offentliga delningar)",
    "Allow people on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot delningar från andra servrar",
    "Allow people on this server to send shares to groups on other servers" : "Tillåt användare på denna server att skicka delningar till grupper på andra servrar",
    "Allow people on this server to receive group shares from other servers" : "Tillåt användare på denna server att ta emot gruppdelningar från andra servrar",
    "The lookup server is only available for global scale." : "Uppslagningstjänsten är endast tillgänglig för global scale.",
    "Search global and public address book for people" : "Sök global och offentlig adressbok för användare",
    "Allow people to publish their data to a global and public address book" : "Tillåt användare att publicera sin data till en global och publik adressbok",
    "Trusted federation" : "Betrodd federation",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Acceptera automatiskt delningar från betrodda federerade konton och grupper som standard",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Dela med mig genom mitt #Nextcloud federerade moln-ID, se {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dela med mig genom mitt #Nextcloud federerade moln-ID",
    "Share with me via Nextcloud" : "Dela med mig via Nextcloud",
    "Cloud ID copied" : "Moln-ID kopierat",
    "Copy" : "Kopiera",
    "Clipboard not available. Please copy the cloud ID manually." : "Urklipp är inte tillgängligt. Kopiera moln-ID manuellt.",
    "Copied!" : "Kopierad!",
    "Federated Cloud" : "Federerat moln",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dela med alla som använder en {productName}-server eller andra Open Cloud Mesh (OCM) -kompatibla servrar och tjänster! Anger bara sitt federerade moln-ID i delningsrutan. Det ser ut som person@cloud.example.com",
    "Your Federated Cloud ID" : "Ditt federerade Moln-ID:",
    "Share it so your friends can share files with you:" : "Dela det så att dina vänner kan dela filer med dig:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (tidigare Twitter)",
    "formerly Twitter" : "tidigare Twitter",
    "Mastodon" : "Mastodon",
    "Bluesky" : "Bluesky",
    "Add to your website" : "Lägg till på din hemsida",
    "Share with me via {productName}" : "Dela med mig via {productName}",
    "HTML Code:" : "HTML Kod:",
    "Cancel" : "Avbryt",
    "Add remote share" : "Lägg till extern delning",
    "Remote share" : "Extern delning",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till extern delning {name} från {owner}@{remote}?",
    "Remote share password" : "Lösenord för extern delning",
    "Incoming share could not be processed" : "Inkommande delning kunde inte behandlas",
    "Cloud ID copied to the clipboard" : "Moln-ID kopierades till urklippet",
    "Copy to clipboard" : "Kopiera till urklipp",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dela med alla som använder en Nextcloud-server eller andra Open Cloud Mesh (OCM) -kompatibla servrar och tjänster! Anger bara sitt federerade moln-ID i delningsrutan. Det ser ut som person@cloud.example.com"
},
"nplurals=2; plural=(n != 1);");
